it("should add node-libs-browser to target web by default", function() {
	expect(process.browser).toBe(true);
});
